package esac.archive.lpf.common.constants.client;

/**
 * Utility class to store String values shared by Web and Data Distribution
 * applications.
 * 
 * @author Monica F Barreiro Copyright (c) 2015 - European Space Agency
 * 
 */
public class LpfRetrievalConstants {

	/**
	 * Default constructor, it should not be called.
	 */
	protected LpfRetrievalConstants() {
		// prevents calls from subclass
		throw new UnsupportedOperationException();
	}

	// //////////////////////////////////////////////////////////////////////////////
	// / Generic Retrieval constants (should be in ABSI?) ///
	// //////////////////////////////////////////////////////////////////////////////

	/** Expected Retrieval element keys */
	public static final String RETRIEVAL_TYPE_KEY = "RetrievalType";
	public static final String PRODUCT_TYPE_KEY = "ProductType";

	/** Product/Postcard Retrieval types. */
	public static final String PRODUCT_RETRIEVAL_TYPE = "PRODUCT";
	public static final String POSTCARD_RETRIEVAL_TYPE = "POSTCARD";
	
    /** Several retrieval element keys. */
    public static final String MUST_PARAMS_QB_KEY = "MUST_PARAMS_QUERY_BEAN";

	/**
	 * Defines the possible types of retrieval in the Data Distribution: product
	 * or postcard.
	 */
	public enum RetrievalType {
		PRODUCT(PRODUCT_RETRIEVAL_TYPE), POSTCARD(POSTCARD_RETRIEVAL_TYPE);

		private final String symbol;

		RetrievalType(String symbol) {
			this.symbol = symbol;
		}

		@Override
		public String toString() {
			return symbol;
		}

		public String getKey() {
			return LpfRetrievalConstants.RETRIEVAL_TYPE_KEY;
		}
	}

	// List of product types in Lisa Pathfinder SA
	public static enum LpfProductType {
		// Analysis objects
		ANALYSIS_OBJECT("Analysis Object"),

		// Documents
		DOCUMENT("Document"),

		// Documents
		SERVICE_DOCUMENT("Service Document"),

		// Analysis packages
		ANALYSIS_PACKAGE("Analysis Package"),

		// Must parameters
		MUST_PARAMS("MUST parameters"),

	    // DDS
        DDS("DDS");
        
		// Label to be shown in the UI
		private String label;

		/**
		 * Default Constructor
		 * 
		 * @param label
		 */
		private LpfProductType(String label) {
			this.label = label;
		}

		@Override
		public String toString() {
			return label;
		}
	}

}
